# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ostorlab/agent/message/proto/v3/asset/store/ios_store/developer/developer.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\nOostorlab/agent/message/proto/v3/asset/store/ios_store/developer/developer.proto\x12?ostorlab.agent.message.proto.v3.asset.store.ios_store.developer\"_\n\x07Message\x12\x11\n\tbundle_id\x18\x01 \x01(\t\x12\x11\n\tdeveloper\x18\x02 \x01(\t\x12\x15\n\rdeveloper_url\x18\x03 \x01(\t\x12\x17\n\x0f\x64\x65veloper_email\x18\x04 \x01(\t')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ostorlab.agent.message.proto.v3.asset.store.ios_store.developer.developer_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MESSAGE._serialized_start=148
  _MESSAGE._serialized_end=243
# @@protoc_insertion_point(module_scope)
