import{d as o,L as s,af as n,M as a,N as i,i as p,t as m}from"./BL5insM1.js";import{e as c,u}from"./Cwi_4l8S.js";import{u as l}from"./Cx2eLIer.js";import{V as d}from"./CsXS3ljq.js";import{_ as f}from"./DlAUqK2U.js";import"./DPMCFCL9.js";import"./C_VG9WJP.js";import"./CXW38r1j.js";import"./DilUGdDb.js";import"./DkCZQGJD.js";import"./BvH6OxSR.js";const _=o({name:"Vulnerability",components:{VulnerabilityDetail:d},data(){return{scanner:{endpoint:"",name:"",apiKey:""}}},computed:{...s(l,["scanners"])},mounted(){const e=this.scanners.find(r=>c(r.endpoint)===(this._.provides[n]||this.$route).params.scanner);e===void 0?(this.reportError("Scanner not found"),this.$router.push({name:"scan-list"})):this.scanner=e},methods:{...a(u,["reportError"])}});function h(e,r,v,$,y,S){const t=p("VulnerabilityDetail");return m(),i(t,{"scan-id":(e._.provides[n]||e.$route).params.scan,scanner:e.scanner,"vuln-title":(e._.provides[n]||e.$route).params.vuln},null,8,["scan-id","scanner","vuln-title"])}const L=f(_,[["render",h]]);export{L as default};
